Quick start
-----------

1. Install djangorestframework

    pip install djangorestframework

1. Add to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'djvue',
        ...
    ]

